"""

    __version__.py
    ~~~~~~~~~~~~~~

    Metadata of the Module.

"""
__title__ = "sxcu"
__description__ = "Python API wraper for sxcu.net"
__url__ = "https://sxcu.syrusdark.website"
__version__ = "2.0.0"
__author__ = "Naveen M K"
__license__ = "Apache 2.0"
__copyright__ = "Copyright 2020 Naveen M K"
