"""
    SXCU
    ~~~~

    Python API wrapper for sxcu.net.

    :copyright: Copyright 2020 by Naveen M K
    :license: Apache-2.0 , see LICENSE for details.

"""
from .__version__ import __author__  # noqa F401
from .__version__ import __copyright__  # noqa F401
from .__version__ import __description__  # noqa F401
from .__version__ import __license__  # noqa F401
from .__version__ import __title__  # noqa F401
from .__version__ import __url__  # noqa F401
from .__version__ import __version__  # noqa F401
from .sxcu import SXCU, OGProperties  # noqa F401
